# Command line interface

Not all dependencies for the command line interface utilities are not installed by default. Please use the `cli` extra during installation.

-----------------------------

::: mkdocs-click
    :module: geo_track_analyzer.cli
    :command: update_elevation
    :prog_name: enhance-elevation

-----------------------------

::: mkdocs-click
    :module: geo_track_analyzer.cli
    :command: extract_track
    :prog_name: extract-fit-track